%define distname spring_%{version}

# No shared library, and the cmake build currently has internal linking
# issues - AdamW 2008/12
%define _disable_ld_no_undefined	1

Summary:	Realtime strategy game (inspired by Total Annihilation)
Name:		spring
Version:	0.78.2.1
Release:	%mkrel 2
Source0:	http://spring.clan-sy.com/dl/%{name}_%{version}_src.tar.lzma
# use system luxi:
Patch1:		spring-0.78.1.1-luxi.patch
# (Anssi 01/2008) put unitsync.log into ~/.spring, it ends up in pwd when some
# external tools dlopen unitsync.so:
# FIXME: the code completely changed with 0.78. I'm not sure if it still
# needs to be patched, but if so, it needs to be re-diffed. Patch is
# disabled below - AdamW 2009/01
Patch2:		spring-0.77-unitsynclog.patch
License:	GPLv2+
Group:		Games/Strategy
URL:		http://taspring.clan-sy.com/
BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}-buildroot
BuildRequires:	SDL-devel
BuildRequires:	boost-devel
BuildRequires:	desktop-file-utils
BuildRequires:	devil-devel
BuildRequires:	freetype2-devel
BuildRequires:	glew-devel
BuildRequires:	mesaglu-devel
BuildRequires:	openal-devel
BuildRequires:	libogg-devel
BuildRequires:	libvorbis-devel
BuildRequires:	libxcursor-devel
BuildRequires:	python-devel
BuildRequires:	cmake
BuildRequires:	zip
BuildRequires:	zlib-devel
%if %{mdkversion} >= 200810
BuildRequires:	java-rpmbuild
%else
BuildRequires:	jpackage-utils
BuildRequires:	java-devel-icedtea
%define java_home %{_jvmdir}/java-icedtea
%endif
Obsoletes:	%{name}-data < 0.75
Requires:	x11-font-bh-ttf
# Some mod is required, this is the one that was shipped with
# spring-data:
Suggests:	spring-mod-nanoblobs
# Some map is required, these are the default maps from the
# installer:
Suggests:	spring-maps-default
# Internet lobby and springsettings:
Suggests:	springlobby

%description
Spring is a 3D realtime strategy game. It was inspired by Total
Annihilation and has the same features Total Annihilation had, and
more.

%prep
%setup -q -n %{distname}
%patch1 -p1 -b .luxi
# See above FIXME notice - AdamW 2009/01
#patch2 -p1
perl -pi -e 's,%{name}.png,%{name},g' rts/%{name}.desktop

cat > README.install.urpmi <<EOF
If you want to install additional mods and maps that are not available as
Mandriva packages, you can install them inside your homedir in subdirectories
.spring/maps and .spring/mods.
EOF

%build
# Spring has both scons and cmake build systems. The cmake one is newer
# (so presumably preferred upstream), the scons one has problems in
# install phase (some stuff won't install to buildroot), and cmake is
# just...nicer. - AdamW 2008/12
%cmake -DBINDIR=%{_gamesbindir} -DLIBDIR=%{_lib}/%{name} -DJAVA_INCLUDE_PATH=%{java_home}/include -DJAVA_INCLUDE_PATH2=%{java_home}/include/linux -DJAVA_AWT_INCLUDE_PATH=%{java_home}/include
%make

%install
rm -rf %{buildroot}
pushd build
%makeinstall_std
popd

perl -pi -e 's|^Exec=.*|Exec=%{_gamesbindir}/%{name}|' %{buildroot}%{_datadir}/applications/%{name}.desktop
desktop-file-install \
  --vendor="" \
  --remove-category="Application" \
  --dir %{buildroot}%{_datadir}/applications %{buildroot}%{_datadir}/applications/*

install -d -m755 %{buildroot}%{_sysconfdir}/%{name}
echo '$HOME/.spring' > %{buildroot}%{_sysconfdir}/%{name}/datadir
echo '%{_gamesdatadir}/%{name}' >> %{buildroot}%{_sysconfdir}/%{name}/datadir

install -d -m755 %{buildroot}%{_gamesdatadir}/%{name}/{mods,maps}

%if %mdkversion < 200900
%post
%update_mime_database
%endif
%if %mdkversion < 200900
%postun
%clean_mime_database
%endif

%clean
rm -rf %{buildroot}

%files
%defattr(-,root,root)
%doc Documentation/Spring*.txt Documentation/userdocs/* Documentation/cmds.txt
%doc README.install.urpmi
%{_sysconfdir}/%{name}
%{_gamesbindir}/%{name}
%{_gamesbindir}/%{name}-dedicated
%{_gamesdatadir}/%{name}
%{_datadir}/pixmaps/*.png
%{_datadir}/applications/%{name}.desktop
%{_datadir}/mime/packages/%{name}.xml
%{_libdir}/%{name}



%changelog
* Thu Mar 12 2009 Emmanuel Andry <eandry@mandriva.org> 0.78.2.1-2mdv2009.1
+ Revision: 354302
- rebuild for new boost

* Wed Jan 21 2009 Adam Williamson <awilliamson@mandriva.org> 0.78.2.1-1mdv2009.1
+ Revision: 332300
- drop literal.patch (fixed upstream)
- new release 0.78.2.1
- temporarily disable unitsynclog.patch (code has changed completely, may no
  longer be needed)
- add literal.patch (fix two string literal errors, reported upstream)
- rediff luxi.patch
- new release 0.78.1.1

* Sat Dec 20 2008 Funda Wang <fundawang@mandriva.org> 0.77b5-2mdv2009.1
+ Revision: 316583
- rebuild for new boost

* Sun Dec 14 2008 Adam Williamson <awilliamson@mandriva.org> 0.77b5-1mdv2009.1
+ Revision: 314119
- rebuild for new boost
- update file lists
- do update_mime_database in %%post for older releases
- make sure to set all necessary paths for cmake
- drop messy scons stuff
- switch to cmake buildsystem: it's less painful than scons
- buildrequires libxcursor-devel
- rediff unitsynclog.patch
- drop javapath.patch (not needed with the cmake buildsystem, can all be done
  with cmake parameters)
- rediff luxi.patch
- tabs not spaces
- disable ld_noundefined (no shared lib, and the cmake system has underlinking
  issues)
- drop unnecessary defines

* Sat Jan 05 2008 Anssi Hannula <anssi@mandriva.org> 0.76b1-1mdv2008.1
+ Revision: 145679
- 0.76b1
- rediff luxi.patch
- fix java support (javapath.patch)
- create unitsync.log always in ~/.spring, not in pwd (unitsynclog.patch)
- drop spring-data and add suggests to a default mod, mappack and lobby
- build with strip=0
- use parallel build
- provide directories for maps and mods
- provide documentation and README.install.urpmi
- disable ccache as the configure script does not like it

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tvignaud@mandriva.com>
    - kill re-definition of %%buildroot on Pixel's request

  + Funda Wang <fundawang@mandriva.org>
    - BR java things
    - New version 0.75b2

  + Adam Williamson <awilliamson@mandriva.org>
    - hopefully fix conflicts with spring-data package
    - fix issues in XDG menu entry
    - new license policy

* Mon Apr 30 2007 Olivier Blin <oblin@mandriva.com> 0.74-0.b3.1mdv2008.0
+ Revision: 19551
- beta 3


* Sun Feb 04 2007 Anssi Hannula <anssi@mandriva.org> 0.74-0.b2.2mdv2007.0
+ Revision: 116164
- add $HOME/.spring as r/w datadir
- own %%{_libdir}/%%{name}

* Tue Jan 23 2007 Olivier Blin <oblin@mandriva.com> 0.74-0.b2.1mdv2007.1
+ Revision: 112364
- fix libdir on x86_64
- use scons configure to set installprefix
- buildrequires zip (to build sdz files)
- buildrequire scons (obviously)
- initial Spring release
- renamed taspring as spring (new upstream name)
- Created package structure for taspring.

  + Nicolas Lécureuil <neoclust@mandriva.org>
    - New version 0.74 Beta2

